Module: Google::Cloud::Translate
- Defined in:
- lib/google/cloud/translate.rb,
lib/google/cloud/translate/helpers.rb,
lib/google/cloud/translate/version.rb
Constant Summary collapse
- VERSION =
"3.9.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.translate| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-translate library.
-
.translation_service(version: :v3, transport: :grpc, &block) ⇒ ::Object
Create a new client object for TranslationService.
-
.translation_service_available?(version: :v3, transport: :grpc) ⇒ boolean
Determines whether the TranslationService service is supported by the current client.
-
.translation_v2_service(project_id: nil, credentials: nil, key: nil, scope: nil, retries: nil, timeout: nil, endpoint: nil) ⇒ Google::Cloud::Translate::V2::Api
Creates a new object for connecting to the legacy V2 version of the Cloud Translation API.
Class Method Details
.configure {|::Google::Cloud.configure.translate| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-translate library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
147 148 149 150 151 |
# File 'lib/google/cloud/translate.rb', line 147 def self.configure yield ::Google::Cloud.configure.translate if block_given? ::Google::Cloud.configure.translate end |
.translation_service(version: :v3, transport: :grpc, &block) ⇒ ::Object
Create a new client object for TranslationService.
By default, this returns an instance of
Google::Cloud::Translate::V3::TranslationService::Client
for a gRPC client for version V3 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the TranslationService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the TranslationService service. You can determine whether the method will succeed by calling translation_service_available?.
About TranslationService
Provides natural language translation operations.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/translate.rb', line 75 def self.translation_service version: :v3, transport: :grpc, &block require "google/cloud/translate/#{version.to_s.downcase}" package_name = Google::Cloud::Translate .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Translate.const_get(package_name).const_get(:TranslationService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.translation_service_available?(version: :v3, transport: :grpc) ⇒ boolean
Determines whether the TranslationService service is supported by the current client. If true, you can retrieve a client object by calling translation_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the TranslationService service, or if the versioned client gem needs an update to support the TranslationService service.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/google/cloud/translate.rb', line 99 def self.translation_service_available? version: :v3, transport: :grpc require "google/cloud/translate/#{version.to_s.downcase}" package_name = Google::Cloud::Translate .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Translate.const_get package_name return false unless service_module.const_defined? :TranslationService service_module = service_module.const_get :TranslationService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.translation_v2_service(project_id: nil, credentials: nil, key: nil, scope: nil, retries: nil, timeout: nil, endpoint: nil) ⇒ Google::Cloud::Translate::V2::Api
Creates a new object for connecting to the legacy V2 version of the Cloud Translation API.
Like other Cloud Platform services, Google Cloud Translation API supports authentication using a project ID and OAuth 2.0 credentials. In addition, it supports authentication using a public API access key. (If both the API key and the project and OAuth 2.0 credentials are provided, the API key will be used.) Instructions and configuration options are covered in the Authentication Guide.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/google/cloud/translate/helpers.rb', line 90 def self.translation_v2_service project_id: nil, credentials: nil, key: nil, scope: nil, retries: nil, timeout: nil, endpoint: nil require "google/cloud/translate/v2" Google::Cloud::Translate::V2.new project_id: project_id, credentials: credentials, key: key, scope: scope, retries: retries, timeout: timeout, endpoint: endpoint end |